@@ -1,5 +1,5 @@
 """Volume gql requests for Move UGC SDK."""
-from move_ugc.gql_requests.additional_file import expand_outputs_format
+from move_ugc.gql_requests.additional_file import expand_outputs
 from move_ugc.gql_requests.camera_settings import expand_sources_w_camera_settings
 from move_ugc.gql_requests.client import expand_client_query
 from move_ugc.schemas.constants import CLIENT_LITERAL, OUTPUTS_LITERAL, SOURCES_LITERAL
@@ -66,7 +66,7 @@ retrieve_human_volume = UgcGql(
     expand={
         CLIENT_LITERAL: expand_client_query,
         SOURCES_LITERAL: expand_sources_w_camera_settings,
-        OUTPUTS_LITERAL: expand_outputs_format,
+        OUTPUTS_LITERAL: expand_outputs,
     },
 )
 
@@ -101,6 +101,6 @@ list_query = UgcGql(
     expand={
         CLIENT_LITERAL: expand_client_query,
         SOURCES_LITERAL: expand_sources_w_camera_settings,
-        OUTPUTS_LITERAL: expand_outputs_format,
+        OUTPUTS_LITERAL: expand_outputs,
     },
 )
