@@ -1,7 +1,6 @@
 """Take service for Move UGC SDK."""
 
 from typing import Any, Dict, List, Optional
-from warnings import warn
 
 from move_ugc.gql_requests.job import create as create_query
 from move_ugc.gql_requests.job import create_multicam, list_query
@@ -9,7 +8,7 @@ from move_ugc.gql_requests.job import retrieve as retrieve_query
 from move_ugc.gql_requests.job import update as update_query
 from move_ugc.schemas.commons import ListBase, SortDirection, get_default_page_size
 from move_ugc.schemas.constants import ALLOWED_EXPAND_ATTRS
-from move_ugc.schemas.job import JobOptions, JobType
+from move_ugc.schemas.job import ClipWindow, JobOptions, JobType
 from move_ugc.services.base import BaseService
 
 
@@ -33,51 +32,13 @@ class JobService(BaseService[JobType]):
 
     _schema = JobType
 
-    def create(  # noqa: WPS211
-        self,
-        take_id: str,
-        name: Optional[str] = "",
-        metadata: Optional[Dict[str, Any]] = None,
-        options: Optional[JobOptions] = None,
-        expand: Optional[List[ALLOWED_EXPAND_ATTRS]] = None,
-    ) -> JobType:
-        """Create a singlecam job in MoveUGC.
-
-        Args:
-            take_id:
-                id of the take to be used for creating the job.
-            name:
-                name to be used for creating the job.
-            metadata:
-                metadata to be used for creating the job. This should be a valid json string.
-            options:
-                options to be used for creating the job.
-            expand:
-                list of fields to be expanded.
-                Currently only `client`, `take` and `outputs` are supported.
-
-        Returns:
-            Job instance of Pydantic model type.
-        """
-        warn(
-            "This method is deprecated. Use create_singlecam instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.create_singlecam(
-            take_id=take_id,
-            name=name,
-            metadata=metadata,
-            options=options,
-            expand=expand,
-        )
-
     def create_singlecam(  # noqa: WPS211
         self,
         take_id: str,
         name: Optional[str] = "",
         metadata: Optional[Dict[str, Any]] = None,
         options: Optional[JobOptions] = None,
+        clip_window: Optional[ClipWindow] = None,
         outputs: Optional[List[str]] = None,
         expand: Optional[List[ALLOWED_EXPAND_ATTRS]] = None,
     ) -> JobType:
@@ -94,6 +55,9 @@ class JobService(BaseService[JobType]):
                 options to be used for creating the job.
                 Check all the valid allowed options in the API documentation.
                 https://move-ai.github.io/move-ugc-api/schema/#optionsinput
+            clip_window:
+                The clip window that you want to process.
+                If not provided the entire video is processed
             outputs:
                 list of output types to be created for this job.
             expand:
@@ -113,6 +77,9 @@ class JobService(BaseService[JobType]):
                 "options": options.model_dump(by_alias=True, mode="json"),
                 "outputs": [str(output).upper() for output in outputs or []],
                 "metadata": self.encode_aws_metadata(metadata),
+                "clip_window": clip_window.model_dump(by_alias=True)
+                if clip_window
+                else None,
             },
         )
 
@@ -122,7 +89,9 @@ class JobService(BaseService[JobType]):
         number_of_actors: int,
         options: Optional[JobOptions] = None,
         outputs: Optional[List[str]] = None,
+        rig: Optional[str] = "",
         name: Optional[str] = "",
+        clip_window: Optional[ClipWindow] = None,
         metadata: Optional[Dict[str, Any]] = None,
         expand: Optional[List[ALLOWED_EXPAND_ATTRS]] = None,
     ) -> JobType:
@@ -139,8 +108,13 @@ class JobService(BaseService[JobType]):
                 https://move-ai.github.io/move-ugc-api/schema/#optionsinput
             outputs:
                 list of output types to be created for this job.
+            rig:
+                rig to be used for creating the job.
             name:
                 name to be used for creating the job.
+            clip_window:
+                The clip window that you want to process.
+                If not provided the entire video is processed
             metadata:
                 metadata to be used for creating the job. This should be a valid json string.
             expand:
@@ -161,6 +135,10 @@ class JobService(BaseService[JobType]):
                 "options": options.model_dump(by_alias=True, mode="json"),
                 "outputs": [str(output).upper() for output in outputs or []],
                 "metadata": self.encode_aws_metadata(metadata),
+                "rig": rig,
+                "clip_window": clip_window.model_dump(by_alias=True)
+                if clip_window
+                else None,
             },
         )
 
